from beniutils.task import TaskDataType

devTaskList: list[TaskDataType] = [
    ("demo", {"parA": 123}),
    ("demo", {"parA": 123, "parB": 123}),
    ("demo", None),
]
